/*

 TITLE:          Always running, never the same...

 NAME:           Jaime Vives Piqueres
 COUNTRY:        Valencia, Spain
 EMAIL:          jaime@ctav.es
 WEBPAGE:        http://www.ctav.es/jaime

 TOPIC:          WATER
 COPYRIGHT:      I SUBMIT TO THE STANDARD RAYTRACING COMPETITION COPYRIGHT.

 RENDERER USED:  POVRay 3.1 (C) POVTeam. (POVMSDOS in a W95 DOS box)
 TOOLS USED:     Qedit, to write the POV scripts
                 PC PAINTBRUSH, to retouch height_fields
                 POVRay, to generate some height_fields
                 LView31 to convert TGA to JPG (Quality 85%)
 RENDER TIME:    1 hours 29 minutes 45.0 seconds (so little?, hmmm...)
 HARDWARE USED:  Intel PPro180 256k cache, main board Intel VS440FX, 48MB RAM

*/



// *** standard includes ***
#include "colors.inc"
#include "textures.inc"
#include "stones.inc"
#include "woods.inc"
#include "metals.inc"

// *** render control ***
#declare trace_water=       1;
#declare trace_stones=      1;
#declare trace_bed=         1;
#declare trace_sky=         1;
#declare trace_fishes=      1;
#declare trace_plants=      1;

// *** global variables ***
#declare r_stone=seed(161);
#declare sunlight=White*.9+Gold*.5+SkyBlue*.25;
#declare sunlight=sunlight*1.1;
#declare cam_location=<2,9,-30>;
#declare cam_zoom=2.2*z;
#declare cam_look_at=<1,-.2,-12.5>;

// *** common textures ***
#include "i_textur.inc"


// *** river stones ***
#include "i_stnmcr.inc"
#if (trace_stones)
 #debug "Parsing STONES\n"
 #include "i_stones.inc"
 object{u_big_stones translate -7*z}
 object{u_small_stones}
#end


// *** river bed ***
#if (trace_bed)
 #debug "Parsing RIVERBED\n"
 #include "i_rivbed.inc"
 object{riverbed
  scale <30,8,40>
  texture{t_stone}
  translate -2.25*y
  texture{t_wet translate -1.9*y}
 }
#end


// *** water surface ***
#if (trace_water)
 #debug "Parsing WATER\n"
 #include "i_rwater.inc"
 object{river_water
  scale <31.4,.4,40>
  material{
   m_water
   scale 4
   translate 100
  }
  translate <-.2,-1.2,0>
 }
 fog{ colour DarkTan+DarkGreen filter 0.6 distance 6}
 plane{y,-1.2 inverse pigment{Clear}}
#end


// *** fishes ***
#if (trace_fishes)
 #debug "Parsing FISH\n"
 #include "i_fish.inc"
 object{fish
  scale .06
  rotate 45*y
  translate <1.5,-1.6,-12.75>
 }
 object{fish
  scale .06
  rotate 48*y
  translate <1,-1.55,-13>
 }
#end


// *** plants ***
#if (trace_plants)
 #debug "Parsing PLANTS\n"
 #include "i_plants.inc"
 // --- right side ---
 object{ plant
  scale .25
  rotate 360*rand(r_plant)*y
  translate <6.8,-1,-10.5>
 }
 object{ plant
  scale .3
  rotate 360*rand(r_plant)*y
  translate <7,-1,-2>
 }
 object{ plant
  scale .2
  rotate 360*rand(r_plant)*y
  translate <9,-1,3>
 }
 // --- left side ---
 object{ plant
  scale .15
  rotate 360*rand(r_plant)*y
  translate <-4.5,-1,-12.75>
 }
 object{ plant
  scale .3
  rotate 360*rand(r_plant)*y
  translate <-7,-1,-2>
 }
 object{ plant
  scale .3
  rotate 360*rand(r_plant)*y
  translate <-8,-1,-1>
 }
 object{ plant
  scale .3
  rotate 360*rand(r_plant)*y
  translate <-8,-1,0>
 }
 object{ plant
  scale .2
  rotate 360*rand(r_plant)*y
  translate <-4.5,-1,3>
 }
#end


// *** sky spheres ***
#if (trace_sky)
 #debug "Parsing SKY\n"
 #include "i_sky.inc"
 object{sunny_sky}
#end


// *** lights, camera... action! ***
#debug "Parsing LIGTHS\n"
// --- back ambient light ---
light_source{
 cam_location
 sunlight*.6
 shadowless
}
// --- sunlight ---
light_source{
 <4000,9000,15000>
 sunlight
 fade_distance 50000
 fade_power 1
}
// --- camera ---
#debug "Get ready!\n"
camera{
 location cam_location
 direction cam_zoom
 look_at cam_look_at
}


